@@ -12,7 +12,7 @@ class eure_et_loir_eligibilite_faj(Variable):
         reside_eure_et_loir = individu.menage('eure_et_loir_eligibilite_residence', period)
         age = individu('age', period)
         a_entre_18_25_ans = (18 <= age) * (age <= 25)
-        rsa = parameters(period).prestations_sociales.solidarite_insertion.minima_sociaux.rsa
+        rsa = parameters(period).prestations_sociales.solidarite_insertion.minima_sociaux.rsa.rsa_m
         revenus_inferieurs_rsa = individu('eure_et_loir_revenus_nets_du_travail', period) < rsa.montant_de_base_du_rsa
 
         return reside_eure_et_loir * a_entre_18_25_ans * revenus_inferieurs_rsa
